from distutils.core import setup
setup(
    name = 'yeshan',
    version = '1.0',
    descriptin = '这是一个对外发布的模块',
    author = 'yeshan',
    author_email = '2871088500@qq.com',
    py_modules = ['yeshan.demo1','yeshan.demo2']
)